<tal:vhm repeat="id python:vh_map.keys()">
backend <tal:backend replace="id" /> {
    set backend.host = "<tal:zopehost replace='python:vh_map[id]["zope_host"]' />";
    set backend.port = "<tal:zopeport replace='python:vh_map[id]["zope_port"]' />";
}</tal:vhm>


acl purge {
    "localhost";<tal:vhm repeat="vh python:vh_map.values()">
    "<tal:host replace='python:vh["zope_host"]' />";</tal:vhm>
}


sub vcl_recv {

    /* Find the right backend for this request */
    if (!req.url) {
        error 404 "Unknown host";<tal:vhm repeat="id python:vh_map.keys()"><tal:vh 
          define="host python:vh_map[id]['host'];
                  zope_path python:vh_map[id]['zope_path'];
                  sub string:/VirtualHostBase/http/$host:$varnish_port/$zope_path/VirtualHostRoot/$$1">
    } elseif (req.http.host ~ "^<tal:host replace='host' />") {
        set req.backend = <tal:backend replace="id" />;
        set req.url = regsub(req.url, "(.*)", "<tal:sub replace='sub' />");</tal:vh></tal:vhm>
    } else {
        error 404 "Unknown host";
    }

    /* Do not cache if request is not GET or HEAD */
    if (req.request != "GET" && req.request != "HEAD") {
        /* Forward to 'lookup' if request is an authorized PURGE request */
        if (req.request == "PURGE") {
            if (!client.ip ~ purge) {
                error 405 "Not allowed.";
            }
            lookup;
        }
        pipe;
    }

    /* Do not cache if request contains an Expect header */
    if (req.http.Expect) {
        pipe;
    }

    /* Varnish doesn't do INM requests so pass it through */
    if (req.http.If-None-Match) {
        pass;
    }

    /* IMPORTANT: The next five tests force caching for certain items
       even during an authenticated request, if otherwise allowed by
       the cache control headers.  This may allow anonymous access
       to some access-controlled items.
       Depending on your use case, you may wish to modify these conditions
    */
    
    /* (1) Always cache images */
    if (req.url ~ "\.(jpg|jpeg|gif|png)$") {
        lookup;
    }

    /* (2) Always cache scaled ATImages */
    if (req.url ~ "/image_(large|preview|mini|thumb|tile|icon|listing)$") {
        lookup;
    }

    /* (3) Always cache CSS and javascript */
    if (req.url ~ "\.(css|js)$") {
        lookup;
    }

    /* (4) Always cache multimedia */
    if (req.url ~ "\.(svg|swf|ico|mp3|mp4|m4a|ogg|mov|avi|wmv)$") {
        lookup;
    }

    /* (5) Always cache static files */
    if (req.url ~ 
"\.(tiff|tif|pdf|xls|vsd|doc|ppt|pps|vsd|doc|ppt|pps|xls|pdf|sxw|zip|gz|bz2|tgz|tar|rar|odc|odb|odf|odg|odi|odp|ods|odt|sxc|sxd|sxi|sxw|dmg|torrent|deb|msi|iso|rpm)$") {
        lookup;
    }

    /* Do not cache when authenticated via HTTP Basic or Digest Authentication */
    if (req.http.Authenticate || req.http.Authorization) {
        pass;
    }

    /* Do not cache when authenticated via "__ac" or "_ZopeId" cookies */
    if (req.http.Cookie && req.http.Cookie ~ "(__ac=|_ZopeId=)") {
        pass;
    }

    lookup;
}

sub vcl_hit {
    if (req.request == "PURGE") {
        set obj.ttl = 0s;
        error 200 "Purged";
    }
}

sub vcl_miss {

    /* Varnish doesn't do IMS to backend, so if not in cache just pass it through */
    if (req.http.If-Modified-Since) {
        pass;
    }

    if (req.request == "PURGE") {
        error 404 "Not in cache";
    }
}

